nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Mod

Struct Mod 

#[repr(transparent)]
pub struct Mod(pub u32);
Watchdog mode register. This register contains the basic mode and status of the Watchdog Timer.

Tuple Fields

0: u32

Implementations

Source

impl Mod

pub const fn wden(&self) -> Wden

Watchdog enable bit. Once this bit is set to one and a watchdog feed is performed, the watchdog timer will run permanently.

pub const fn set_wden(&mut self, val: Wden)

Watchdog enable bit. Once this bit is set to one and a watchdog feed is performed, the watchdog timer will run permanently.

pub const fn wdreset(&self) -> Wdreset

Watchdog reset enable bit. Once this bit has been written with a 1 it cannot be re-written with a 0.

pub const fn set_wdreset(&mut self, val: Wdreset)

Watchdog reset enable bit. Once this bit has been written with a 1 it cannot be re-written with a 0.

pub const fn wdtof(&self) -> bool

Watchdog time-out flag. Set when the watchdog timer times out, by a feed error, or by events associated with WDPROTECT. Cleared by software writing a 0 to this bit position. Causes a chip reset if WDRESET = 1.

pub const fn set_wdtof(&mut self, val: bool)

Watchdog time-out flag. Set when the watchdog timer times out, by a feed error, or by events associated with WDPROTECT. Cleared by software writing a 0 to this bit position. Causes a chip reset if WDRESET = 1.

pub const fn wdint(&self) -> bool

Warning interrupt flag. Set when the timer is at or below the value in WDWARNINT. Cleared by software writing a 1 to this bit position. Note that this bit cannot be cleared while the WARNINT value is equal to the value of the TV register. This can occur if the value of WARNINT is 0 and the WDRESET bit is 0 when TV decrements to 0.

pub const fn set_wdint(&mut self, val: bool)

Warning interrupt flag. Set when the timer is at or below the value in WDWARNINT. Cleared by software writing a 1 to this bit position. Note that this bit cannot be cleared while the WARNINT value is equal to the value of the TV register. This can occur if the value of WARNINT is 0 and the WDRESET bit is 0 when TV decrements to 0.

pub const fn wdprotect(&self) -> Wdprotect

Watchdog update mode. This bit can be set once by software and is only cleared by a reset.

pub const fn set_wdprotect(&mut self, val: Wdprotect)

Watchdog update mode. This bit can be set once by software and is only cleared by a reset.